import React, { useEffect, useState } from 'react';
import {
  KeyboardAvoidingView,
  Platform,
  SafeAreaView,
  Keyboard,
  Image,
} from 'react-native';
import { TouchableOpacity } from 'react-native';
import { View, Text, TextInput, StyleSheet } from 'react-native';

interface BioProps {
  onChangeText: (params: any) => any;
  value: string;
  onPress: (params: any) => any;
  onBlur: (params: any) => any;
  onChange: (params: any) => any;
  onFocus: (params: any) => any;
  buttonText: string;
  source?: JSX.Element;

  inputContainer: React.CSSProperties;
  keyboardType: any;
  input: any;
  editable: boolean;
  placeholder: string;
  multiline: boolean;
  autoCapitalize: any;
  returnKeyType: any;
  placeholderTextColor: string;
  numberOfLines: number;
  maxLength: number;
  autoFocus: boolean;
  blurOnSubmit: boolean;
  enablesReturnKeyAutomatically: boolean;
  returnKeyLabel: string;
  secureTextEntry: boolean;
  textAlign: any;
  ImageViewStyle: any;
  ContainerViewStyle: any;
  ImageStyle: any;
  MainView: any;
  TextStyle: any;
  InputBoxStyle: any;
  ButtonViewStyle: any;
  ButtonTextStyle: any;
  button: boolean;
  SignupButton: boolean;
  SignupTextStyle: any;
  SingupStyle: any;
  SingupText: string;
  Singup: string;
  SingupClick: (params: any) => any;
  LoginText: string;
}

const Sandy: React.FC<BioProps> = (props): JSX.Element => {
  const [isKeyboardVisible, setKeyboardVisible] = useState(false);

  useEffect(() => {
    const keyboardDidShowListener = Keyboard.addListener(
      'keyboardDidShow',
      () => {
        setKeyboardVisible(true); // or some other action
      }
    );
    const keyboardDidHideListener = Keyboard.addListener(
      'keyboardDidHide',
      () => {
        setKeyboardVisible(false); // or some other action
      }
    );

    return () => {
      keyboardDidHideListener.remove();
      keyboardDidShowListener.remove();
    };
  }, []);
  return (
    <>
      <SafeAreaView style={{ flex: 1 }}>
        <KeyboardAvoidingView
          behavior={Platform.OS == 'android' ? 'height' : 'padding'}
        >
          <View
            style={[
              {
                height: '100%',
                width: '100%',
                // justifyContent: 'center',
              },
              props.MainView,
            ]}
          >
            {props.source ? (
              <View
                style={[
                  {
                    height: isKeyboardVisible ? '40%' : '60%',
                    width: '100%',
                    alignSelf: 'center',
                    justifyContent: 'center',
                  },
                  props.ImageViewStyle,
                ]}
              >
                <Image
                  source={props.source ? props.source : require('./a.jpeg')}
                  style={[
                    styles.backgroundImage,
                    {
                      height: isKeyboardVisible ? 80 : 150,
                      width: isKeyboardVisible ? 80 : 150,
                    },
                    props.ImageStyle,
                  ]}
                />
              </View>
            ) : null}
            <View style={[styles.viewa, props.ContainerViewStyle]}>
              <Text style={[styles.title, props.TextStyle]}>
                {props.LoginText || 'Login'}
              </Text>
              <View style={styles.inputContainer}>
                <TextInput
                  numberOfLines={props.numberOfLines || 1}
                  maxLength={props.maxLength || 50}
                  onChangeText={props.onChangeText}
                  value={props.value}
                  style={[styles.input, props.InputBoxStyle]}
                  returnKeyType={props.returnKeyType || 'done'}
                  keyboardType={props.keyboardType || 'default'}
                  placeholder={props.placeholder || 'write here... '}
                  placeholderTextColor={props.placeholderTextColor || 'grey'}
                  editable={props.editable || true}
                  multiline={props.multiline || false}
                  autoCapitalize={props.autoCapitalize || 'none'}
                  autoFocus={props.autoFocus || false}
                  blurOnSubmit={props.blurOnSubmit || false}
                  enablesReturnKeyAutomatically={
                    props.enablesReturnKeyAutomatically || false
                  }
                  onBlur={props.onBlur}
                  onChange={props.onChange}
                  onFocus={props.onFocus}
                  returnKeyLabel={props.returnKeyLabel || 'default'}
                  secureTextEntry={props.secureTextEntry || false}
                  textAlign={props.textAlign || 'left'}
                />
              </View>
              {props.button ? (
                <TouchableOpacity
                  onPress={props.onPress}
                  style={[styles.buttonView, props.ButtonViewStyle]}
                >
                  <Text style={[styles.buttonText, props.ButtonTextStyle]}>
                    {props.buttonText || 'Continue'}
                  </Text>
                </TouchableOpacity>
              ) : null}
              {props.SignupButton ? (
                <Text
                  style={[
                    styles.title,
                    { fontSize: 15, textAlign: 'center', marginTop: 10 },
                    props.SignupTextStyle,
                  ]}
                >
                  {props.SingupText || "Don't have an account? "}
                  <Text
                    onPress={props.SingupClick}
                    style={[
                      { fontSize: 15, fontWeight: 'bold' },
                      props.SingupStyle,
                    ]}
                  >
                    {props.Singup || 'Sign Up'}
                  </Text>
                </Text>
              ) : null}
            </View>
          </View>
        </KeyboardAvoidingView>
      </SafeAreaView>
    </>
  );
};

const styles = StyleSheet.create({
  backgroundImage: {
    borderRadius: 10,
    alignSelf: 'center',
    resizeMode: 'cover',
    alignItems: 'center',
    // or 'stretch' for a different background image behavior
  },
  viewa: {
    alignSelf: 'center',
    width: '90%',
    height: 'auto',
    // backgroundColor:'red',
    position: 'absolute',
    bottom: 10,
  },
  inputContainer: {
    flexDirection: 'row',
    alignItems: 'center',
    marginBottom: 10,
  },

  buttonView: {
    height: 40,
    width: '100%',
    borderRadius: 10,
    backgroundColor: 'green',
    justifyContent: 'center',
    // padding: 10,
    shadowColor: '#000000',
    shadowOffset: {
      width: 1,
      height: 1,
    },
    elevation: 5,
    shadowRadius: 2,
    shadowOpacity: 0.2,
    borderWidth: 0.3,
  },
  buttonText: {
    textAlign: 'center',
    color: 'white',
    fontSize: 15,
    fontWeight: '600',
  },
  title: {
    fontSize: 25,
    color: 'black',
    marginBottom: 20,
  },

  input: {
    width: '100%',
    height: 40,
    backgroundColor: 'white',
    paddingLeft: 10,
    // marginBottom: 10,
    padding: 10,
    shadowColor: '#000000',
    shadowOffset: {
      width: 1,
      height: 1,
    },
    elevation: 5,
    shadowRadius: 2,
    shadowOpacity: 0.2,
    borderWidth: 0.3,
    borderRadius: 10,
  },
});

export default Sandy;
